In-process test runner for CLI commands.
Invokes a command capturing stdout and return value, without spawning a subprocess.
Usage
result = Cheer.Test.run(MyCommand, ["--port", "8080"])
assert result.return == {:ok, %{port: 8080}}
assert result.output == ""
Summary
Functions
Run a command with the given argv, capturing output and return value.